@@ -1,3 +1,3 @@
 from .api_client import ApiClient
-from .base_client import BaseClient, success_response
+from .base_client import BaseClient
 from .exceptions import ApiClientException, JelasticClientException
