@@ -1,7 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import Dict
 
-from . import ApiClient
+from .api_client import ApiClient
+from .exceptions import JelasticClientException
 
 
 def success_response(response: Dict) -> bool:
@@ -19,10 +20,16 @@ class BaseClient(ABC):
         raise NotImplementedError
 
     def execute(self, fnc: str, **kwargs) -> Dict:
+        two_dotted_function_name = self._fnc(fnc)
         response = self.api_client.execute(
-            self._fnc(fnc),
+            two_dotted_function_name,
             **kwargs
         )
+
+        if not success_response(response):
+            raise JelasticClientException(
+                f"execution of function {two_dotted_function_name} failed", response)
+
         return response
 
     def _fnc(self, fnc_name: str):
